# encoding: utf-8

# author: BrikerMan
# contact: eliyar917@gmail.com
# blog: https://eliyar.biz

# file: test_custom_model.py
# time: 6:07 下午

import unittest
from typing import Dict, Any

from tensorflow import keras

import tests.test_classification.test_bi_lstm_model as base
from kashgari.embeddings import WordEmbedding
from kashgari.layers import L
from kashgari.tasks.classification.abc_model import ABCClassificationModel
from tests.test_macros import TestMacros


class Double_BiLSTM_Model(ABCClassificationModel):
    @classmethod
    def default_hyper_parameters(cls) -> Dict[str, Any]:
        return {
            'layer_lstm1': {
                'units': 128,
                'return_sequences': True
            },
            'layer_lstm2': {
                'units': 64,
                'return_sequences': False
            },
            'layer_dropout': {
                'rate': 0.5
            },
            'layer_output': {

            }
        }

    def build_model_arc(self) -> None:
        config = self.hyper_parameters
        output_dim = self.label_processor.vocab_size
        embed_model = self.embedding.embed_model

        # 定义模型架构
        self.tf_model = keras.Sequential([
            embed_model,
            L.Bidirectional(L.LSTM(**config['layer_lstm1'])),
            L.Bidirectional(L.LSTM(**config['layer_lstm2'])),
            L.Dropout(**config['layer_dropout']),
            L.Dense(output_dim, **config['layer_output']),
            self._activation_layer()
        ])


class TestCustom_Model(base.TestBiLSTM_Model):
    @classmethod
    def setUpClass(cls):
        cls.EPOCH_COUNT = 1
        cls.TASK_MODEL_CLASS = Double_BiLSTM_Model
        cls.w2v_embedding = WordEmbedding(TestMacros.w2v_path)


if __name__ == "__main__":
    unittest.main()



# encoding: utf-8
"""
@author: BrikerMan
@contact: eliyar917@gmail.com
@blog: https://eliyar.biz

@version: 1.0
@license: Apache Licence
@file: __init__.py
@time: 2019-05-17 11:15

"""

import os
from distutils.version import LooseVersion
from typing import Any, Dict

os.environ["TF_KERAS"] = "1"
os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"

custom_objects: Dict[str, Any] = {}


def check_tfa_version(tf_version: str) -> str:
    if LooseVersion(tf_version) < "2.2.0":
        return "0.9.1"
    elif LooseVersion(tf_version) < "2.3.0":
        return "0.11.2"
    else:
        return "0.13.0"


def dependency_check() -> None:
    import tensorflow as tf

    tfa_version = check_tfa_version(tf_version=tf.__version__)
    try:
        import tensorflow_addons as tfa
    except:
        raise ImportError(
            "Kashgari request tensorflow_addons, please install via the "
            f"`$pip install tensorflow_addons=={tfa_version}`"
        )


dependency_check()

from kashgari import corpus, embeddings, layers, macros, processors, tasks, utils
from kashgari.__version__ import __version__
from kashgari.macros import config

custom_objects = layers.resigter_custom_layers(custom_objects)
